==> haskell-edisonapi-1.3.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonAPI
version: 1.3.1
id: EdisonAPI-1.3.1-IaG6hy9pPqn2w7z99RdxUC
key: EdisonAPI-1.3.1-IaG6hy9pPqn2w7z99RdxUC
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (API)
description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.
category: Data Structures
author: Chris Okasaki
exposed: True
indefinite: False
exposed-modules:
    Data.Edison Data.Edison.Assoc Data.Edison.Coll
    Data.Edison.Coll.Utils Data.Edison.Prelude Data.Edison.Seq
    Data.Edison.Seq.ListSeq Data.Edison.Sym
abi: 980cab4f4eded17706a2e2838b706a46
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonAPI-1.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonAPI-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/EdisonAPI-1.3.1
hs-libraries: HSEdisonAPI-1.3.1-IaG6hy9pPqn2w7z99RdxUC
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html: /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisonapi-1.3.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonAPI
version: 1.3.1
id: EdisonAPI-1.3.1-95fDYXS0D7a74bXECwc4er
key: EdisonAPI-1.3.1-95fDYXS0D7a74bXECwc4er
license: MIT
maintainer: robdockins AT fastmail DOT fm
author: Chris Okasaki
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (API)
description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.
category: Data Structures
abi: 99ed633a2e3c33b3bd0e738e465c06ef
exposed: True
exposed-modules:
    Data.Edison Data.Edison.Assoc Data.Edison.Coll
    Data.Edison.Coll.Utils Data.Edison.Prelude Data.Edison.Seq
    Data.Edison.Seq.ListSeq Data.Edison.Sym
import-dirs: /usr/lib/ghc-8.4.3/site-local/EdisonAPI-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/EdisonAPI-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/EdisonAPI-1.3.1
hs-libraries: HSEdisonAPI-1.3.1-95fDYXS0D7a74bXECwc4er
depends:
    base-4.11.1.0 mtl-2.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
haddock-interfaces: /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html: /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
